#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
ttop is CUI graphical system monitor.
this tools is designed for use with tmux.
https://github.com/ton1517/ttop

Usage:
  ttop [--no-color] [--interval <s>] [--no-tmux] [normal | minimal | stack] [horizontal | vertical]
  ttop -h | --help
  ttop -v | --version

Options:
  -h --help           show help.
  -v --version        show version.
  -C --no-color       use monocolor.
  -i --interval <s>   refresh interval(second) [default: 1.0].
  -T --no-tmux        don't use tmux mode.
"""

from . import __version__

import sys
import curses
from multiprocessing import Process

from docopt import docopt

from . import core
from . import color
from . import view
from . import tmux

#=======================================
# Config
#=======================================

EXIT_KEYS = (ord("q"), ord("Q"), 27) # 27:ESC

#=======================================
# Functions
#=======================================

def init_curses():
    """must be called in hook_curses function."""

    ## use terminal color.
    if curses.has_colors():
        curses.use_default_colors()
    ## hide cursor
    curses.curs_set(0)

def create_updater(scr, arguments):
    ss = core.SystemStatus(arguments.interval)
    theme = select_color_theme(arguments)
    layout_class = select_layout_class(arguments)
    layout = layout_class(scr, theme, ss)

    return core.Updater(scr, ss, layout)

def new_pane_and_exec_process(arguments):
    layout_class = select_layout_class(arguments)
    width, height = (layout_class.WIDTH, layout_class.HEIGHT)
    command = " ".join(sys.argv) + " --no-tmux"

    # if horizontal option, split-window -v. if vertical option, split-window -h.
    tmux.split_window(arguments.horizontal, arguments.vertical, command)
    tmux.move_last_pane()
    tmux.resize_pane(width, height)
    tmux.swap_pane()

def select_color_theme(arguments):
    color_table = color.ColorTable()
    return color.MonoColorTheme(color_table) if arguments.no_color else color.DefaultColorTheme(color_table)

def select_layout_class(arguments):
    layout_class = None

    if arguments.normal and arguments.horizontal:
        layout_class = view.HorizontalDefaultLayout
    elif arguments.minimal and arguments.horizontal:
        layout_class = view.HorizontalMinimalLayout
    elif arguments.stack and arguments.horizontal:
        layout_class = view.HorizontalStackLayout
    elif arguments.normal and arguments.vertical:
        layout_class = view.VerticalDefaultLayout
    elif arguments.minimal and arguments.vertical:
        layout_class = view.VerticalMinimalLayout
    elif arguments.stack and arguments.vertical:
        # TODO
        layout_class = view.HorizontalStackLayout

    return layout_class


def start_process(updater):
    p = Process(target=update_handler, args=(updater,))
    p.daemon = True
    p.start()

def update_handler(updater):
    while True:
        updater.update()

def wait_key_and_exit(scr):
    while True:
        c = scr.getch()

        if c in EXIT_KEYS:
            sys.exit()

def hook_curses(scr, arguments):
    init_curses()

    updater = create_updater(scr, arguments)
    start_process(updater)

    wait_key_and_exit(scr)

def main():
    arg_dict = docopt(__doc__, version="ttop "+__version__)
    arguments = core.Arguments(arg_dict)


    if tmux.in_tmux() and not arguments.no_tmux:
        if tmux.get_version() < 1.8:
            print("your tmux version is " + str(tmux.get_version()) + ".")
            print("only support tmux 1.8 or higher.")
            print("you should use --no-tmux option.")
        else:
            new_pane_and_exec_process(arguments)

        sys.exit()

    curses.wrapper(hook_curses, arguments)

if __name__ == "__main__":
    main()



import curses

from . import core

#=======================================
# View components
#=======================================

#--------------------
# HorizontalLineGauge
#--------------------

class HorizontalLineGauge(object):
    """horizontal 1 line gauge.
    example:
        CPU [||||||||||       50%]
    """

    GAUGE_LEFT = "["
    GAUGE_RIGHT = "]"
    GAUGE = "|"
    GAUGE_BLANK = " "

    def __init__(self, scr, color_theme, label, resource):
        self.scr = scr
        self.color_theme = color_theme
        self.label = label
        self.resource = resource

    def draw(self, y, x, width):
        llabel = self.label.ljust(3)
        self.scr.addstr(y, x, llabel, self.color_theme.LABEL)
        self.scr.addstr(self.GAUGE_LEFT, self.color_theme.FRAME)

        (now_y, now_x) = self.scr.getyx()
        width_resource = width - (now_x - x) - (len(self.GAUGE_RIGHT))
        self._draw_resource(now_y, now_x, width_resource)

        self.scr.addstr(self.GAUGE_RIGHT, self.color_theme.FRAME)

    def _draw_resource(self, y, x, width):
        pass

#--------------------
# CPUHorizontalLineGauge
#--------------------

class CPUHorizontalLineGauge(HorizontalLineGauge):

    def _draw_resource(self, y, x, width):
        user_n = int(round(self.resource.userPercent* width))
        system_n = int(round(self.resource.systemPercent * width))

        self.scr.addstr(y, x, self.GAUGE*user_n, self.color_theme.CPU_GAUGE_USER)
        self.scr.addstr(self.GAUGE*system_n, self.color_theme.CPU_GAUGE_SYSTEM)
        self.scr.addstr(self.GAUGE_BLANK * (width-(user_n+system_n)))

        per = str(self.resource.usedPercent)
        start_x = x + width - len(per)
        self.scr.addstr(y, start_x, per, self.color_theme.PERCENT)

#--------------------
# MemoryHorizontalLineGauge
#--------------------

class MemoryHorizontalLineGauge(HorizontalLineGauge):

    def _draw_resource(self, y, x, width):
        used_n = int(round(self.resource.percent * width))

        self.scr.addstr(y, x, self.GAUGE*used_n, self.color_theme.MEM_GAUGE_USED)
        self.scr.addstr(self.GAUGE_BLANK * (width-used_n))

        text = str(self.resource)
        start_x = x + width - len(text)
        self.scr.addstr(y, start_x, text, self.color_theme.PERCENT)

#--------------------
# VerticalLineGauge
#--------------------

class VerticalLineGauge(object):

    GAUGE_TOP = "|~|"
    GAUGE_BOTTOM = "|_|"
    GAUGE = "|=|"
    GAUGE_BLANK = "   "

    def __init__(self, scr, color_theme, label, resource):
        self.scr = scr
        self.color_theme = color_theme
        self.label = label
        self.resource = resource
        self.width = 3

    def draw(self, y, x, height):
        llabel = self.label[:self.width].center(self.width)
        self.scr.addstr(y, x, llabel, self.color_theme.LABEL)
        self.scr.addstr(y+1, x, self.GAUGE_TOP, self.color_theme.FRAME)

        height_resource = height - 3
        self._draw_resource(y+2, x, height_resource)

        self.scr.addstr(y + height-1, x, self.GAUGE_BOTTOM, self.color_theme.FRAME)

    def _draw_resource(self, y, x, height):
        pass

#--------------------
# CPUVerticalLineGauge
#--------------------

class CPUVerticalLineGauge(VerticalLineGauge):

    def _draw_resource(self, y, x, height):
        user_n = int(round(self.resource.userPercent* height))
        system_n = int(round(self.resource.systemPercent * height))

        for i in range(height-(user_n+system_n)):
            self.scr.addstr(y + i, x, self.GAUGE_BLANK)

        now_y = self.scr.getyx()[0] + 1
        for i in range(system_n):
            self.scr.addstr(now_y + i, x, self.GAUGE, self.color_theme.CPU_GAUGE_SYSTEM)

        now_y = self.scr.getyx()[0] + 1
        for i in range(user_n):
            self.scr.addstr(now_y + i, x, self.GAUGE, self.color_theme.CPU_GAUGE_USER)

        last_y = self.scr.getyx()[0] + 1

        per = str(self.resource.usedPercent)[:self.width].rjust(self.width)
        self.scr.addstr(y, x, per, self.color_theme.PERCENT)

#--------------------
# MemoryVerticalLineGauge
#--------------------

class MemoryVerticalLineGauge(VerticalLineGauge):

    def _draw_resource(self, y, x, height):
        used_n = int(round(self.resource.percent * height))

        for i in range(height-used_n):
            self.scr.addstr(y + i, x, self.GAUGE_BLANK)

        now_y = self.scr.getyx()[0] + 1
        for i in range(used_n):
            self.scr.addstr(now_y + i, x, self.GAUGE, self.color_theme.MEM_GAUGE_USED)

        per = str(self.resource.percent)[:self.width].rjust(self.width)
        self.scr.addstr(y, x, per, self.color_theme.PERCENT)

#--------------------
# HorizontalStackView
#--------------------

class HorizontalStackView(object):

    GAUGE_LEFT = "|"
    GAUGE_RIGHT = "|"
    GAUGE_BOTTOM = "_"
    GAUGE = "|"
    GAUGE_BLANK = " "

    def __init__(self, scr, color_theme, label, resource):
        self.scr = scr
        self.color_theme = color_theme
        self.label = label
        self.resource = resource
        self.height = 10

        self.resource_history = core.ResourceHistory(resource.__class__)
        self.resources = []
        self.text = ""

    def draw(self, y, x, width):
        llabel = self.label[:3].ljust(3)
        self.scr.addstr(y+int(self.height/2), x, llabel, self.color_theme.LABEL)
        for i in range(self.height):
            self.scr.addstr(y+i, x+3, self.GAUGE_LEFT, self.color_theme.FRAME)

        width_resource = width - 5

        self.resource_history.pack(width_resource)
        self.resource_history.push(self.resource, width_resource)
        self._draw_resource(y, x+4, width_resource)

        for i in range(self.height):
            self.scr.addstr(y+i, x+width-1, self.GAUGE_LEFT, self.color_theme.FRAME)

    def _draw_text(self, y, x, text, max_width):
        self.scr.addnstr(y, x, text, max_width, self.color_theme.PERCENT)

    def _draw_resource(self, y, x, width):
        for i in range(width):
            self._draw_gauge(y, x + i, self.resource_history.get(i))

    def _draw_gauge(self, y, x, resource):
        pass

#--------------------
# CPUHorizontalStackView
#--------------------

class CPUHorizontalStackView(HorizontalStackView):

    def _draw_resource(self, y, x, width):
        super(CPUHorizontalStackView, self)._draw_resource(y, x, width)
        per = str(self.resource.usedPercent)
        self._draw_text(y, x+width-len(per), per, width)

    def _draw_gauge(self, y, x, resource):
        user_n = int(round(resource.userPercent* self.height))
        system_n = int(round(resource.systemPercent * self.height))

        for i in range(self.height-(user_n+system_n)):
            self.scr.addstr(y + i, x, self.GAUGE_BLANK)

        now_y = self.scr.getyx()[0] + 1
        for i in range(system_n):
            self.scr.addstr(now_y + i, x, self.GAUGE, self.color_theme.CPU_GAUGE_SYSTEM)

        now_y = self.scr.getyx()[0] + 1
        for i in range(user_n):
            self.scr.addstr(now_y + i, x, self.GAUGE, self.color_theme.CPU_GAUGE_USER)

#--------------------
# MemoryHorizontalStackView
#--------------------

class MemoryHorizontalStackView(HorizontalStackView):

    def _draw_resource(self, y, x, width):
        super(MemoryHorizontalStackView, self)._draw_resource(y, x, width)
        text = str(self.resource)
        self.scr.addstr(y, x+width-len(text), text, self.color_theme.PERCENT)

    def _draw_gauge(self, y, x, resource):
        used_n = int(round(resource.percent * self.height))

        for i in range(self.height-used_n):
            self.scr.addstr(y + i, x, self.GAUGE_BLANK)

        now_y = self.scr.getyx()[0] + 1
        for i in range(used_n):
            self.scr.addstr(now_y + i, x, self.GAUGE, self.color_theme.MEM_GAUGE_USED)

#=======================================
# Layout
#=======================================

#--------------------
# Layout
#--------------------

class Layout(object):

    WIDTH = None
    HEIGHT = None

    def __init__(self, scr, color_theme, system_status):
        self.scr = scr
        self.color_theme = color_theme
        self.system_status = system_status

        self._init()

    def _init(self):
        pass

    def draw(self):
        pass

#--------------------
# HorizontalMinimalLayout
#--------------------

class HorizontalMinimalLayout(Layout):

    WIDTH = None
    HEIGHT = 2

    def _init(self):
        self.cpu = CPUHorizontalLineGauge(self.scr, self.color_theme, "CPU", self.system_status.cpu)
        self.memory = MemoryHorizontalLineGauge(self.scr, self.color_theme, "MEM", self.system_status.memory)

    def draw(self):
        (height, width) = self.scr.getmaxyx()
        self.cpu.draw(0, 0, width)
        self.memory.draw(1, 0, width)

#--------------------
# HorizontalDefaultLayout
#--------------------

class HorizontalDefaultLayout(Layout):

    WIDTH = None
    HEIGHT = 3 + int((1+core.CPU.NUM_CPUS)/2)

    def _init(self):
        self.cpu = CPUHorizontalLineGauge(self.scr, self.color_theme, "CPU", self.system_status.cpu)
        self.each_cpu = [CPUHorizontalLineGauge(self.scr, self.color_theme, str(i+1), cpu) for i, cpu in enumerate(self.system_status.each_cpu)]
        self.memory = MemoryHorizontalLineGauge(self.scr, self.color_theme, "MEM", self.system_status.memory)
        self.swap = MemoryHorizontalLineGauge(self.scr, self.color_theme, "SWP", self.system_status.swap)

    def draw(self):
        (height, width) = self.scr.getmaxyx()
        center = int(width/2)

        self.cpu.draw(0, 0, width)

        for i, cpu in enumerate(self.each_cpu):
            y, x =  (int(i/2)+1, 0 if i%2 == 0  else center)
            w = center if i%2 == 0 else width-center
            cpu.draw(y, x, w)

        y = int(len(self.each_cpu)/2)+1
        self.memory.draw(y, 0, width)
        self.swap.draw(y+1, 0, width)

#--------------------
# VerticalMinimalLayout
#--------------------

class VerticalMinimalLayout(Layout):

    WIDTH = 3*2
    HEIGHT = None

    def _init(self):
        self.cpu = CPUVerticalLineGauge(self.scr, self.color_theme, "CPU", self.system_status.cpu)
        self.memory = MemoryVerticalLineGauge(self.scr, self.color_theme, "MEM", self.system_status.memory)

    def draw(self):
        (height, width) = self.scr.getmaxyx()
        self.cpu.draw(0, 0, height)
        self.memory.draw(0, self.cpu.width, height)

#--------------------
# VerticalDefaultLayout
#--------------------

class VerticalDefaultLayout(Layout):

    WIDTH = 9 + 3*int((1+core.CPU.NUM_CPUS)/2)
    HEIGHT = None

    def _init(self):
        self.cpu = CPUVerticalLineGauge(self.scr, self.color_theme, "CPU", self.system_status.cpu)
        self.each_cpu = [CPUVerticalLineGauge(self.scr, self.color_theme, str(i+1), cpu) for i, cpu in enumerate(self.system_status.each_cpu)]
        self.memory = MemoryVerticalLineGauge(self.scr, self.color_theme, "MEM", self.system_status.memory)
        self.swap = MemoryVerticalLineGauge(self.scr, self.color_theme, "SWP", self.system_status.swap)

    def draw(self):
        (height, width) = self.scr.getmaxyx()
        gauge_w = self.cpu.width
        center = int(height/2)

        self.cpu.draw(0, 0, height)

        for i, cpu in enumerate(self.each_cpu):
            y, x =  (0 if i%2 == 0  else center, (int(i/2)+1)*gauge_w)
            h = center if i%2 == 0 else height-center
            cpu.draw(y, x, h)

        x = int((len(self.each_cpu)+1)/2+1)*gauge_w
        self.memory.draw(0, x, height)
        self.swap.draw(0, x+gauge_w, height)

#--------------------
# HorizontalStackLayout
#--------------------

class HorizontalStackLayout(Layout):

    WIDTH = None
    HEIGHT = 10

    def _init(self):
        self.cpu = CPUHorizontalStackView(self.scr, self.color_theme, "CPU", self.system_status.cpu)
        self.memory = MemoryHorizontalStackView(self.scr, self.color_theme, "MEM", self.system_status.memory)

    def draw(self):
        (height, width) = self.scr.getmaxyx()
        center = int(width/2)
        self.cpu.draw(0, 0, center)
        self.memory.draw(0, center, center)





from hurry.filesize import size
import psutil
import copy

#=======================================
# Core Classes
#=======================================

#--------------------
# Percent
#--------------------

class Percent(float):
    """Percent type.

    >>> p = Percent(95.1)
    >>> print(p.real)
    0.951
    >>> print(p)
    95%
    """

    def __new__(cls, value=0.0):
        value = value/100

        return float.__new__(cls, value)

    def __init__(self, percent):
        self.percent = percent

    def __str__(self):
        return str(int(round(self.percent))) + "%"

#--------------------
# Bytes
#--------------------

class Bytes(int):

    def __str__(self):
        return size(self.real)

#--------------------
# CPU
#--------------------

class CPU(object):

    NUM_CPUS = psutil.NUM_CPUS

    def __init__(self, user=0, system=0, idle=0):
        self.update(user, system, idle)

    def update(self, user, system, idle):
        self.userPercent = Percent(user)
        self.systemPercent = Percent(system)
        self.usedPercent =  Percent(user+system)
        self.idlePercent = Percent(idle)

    def __str__(self):
        return str(self.usedPercent)

#--------------------
# Memory
#--------------------

class Memory(object):

    def __init__(self, total=1, used=0):
        self.update(total, used)

    def update(self, total, used):
        self.total = Bytes(total)
        self.used = Bytes(used)
        self.percent = Percent((1.0*used/total)*100)

    def __str__(self):
        return "%s/%s %s" % (self.used, self.total, self.percent)

#--------------------
# ResourceHistory
#--------------------

class ResourceHistory(object):

    def __init__(self, resource_class):
        self.resource_class = resource_class
        self.resources = []

    def get(self, index):
        return self.resources[index]

    def pack(self, length):
        res_len = len(self.resources)
        if length < res_len:
            del_len = res_len - length
            del self.resources[:del_len]
        elif length > res_len:
            push_len = length - res_len
            self.resources = [self.resource_class() for i in range(push_len)] + self.resources

    def push(self, resource, max_len):
        self.resources.append(copy.copy(resource))
        if len(self.resources) > max_len:
            del_len = len(self.resources) - max_len
            del self.resources[:del_len]

#--------------------
# SystemStatus
#--------------------

class SystemStatus(object):
    """this class have system status, CPU percent, Memory percent, etc."""

    def __init__(self, update_interval):
        self.update_interval = update_interval
        self.cpu = CPU()
        self.each_cpu = [CPU() for i in range(CPU.NUM_CPUS)]
        self.memory = Memory()
        self.swap = Memory()

    def update(self):
        """poll system status.(blocking)"""
        times_percent = psutil.cpu_times_percent(interval=self.update_interval, percpu=True)

        self.__update_cpu(times_percent)
        for i, c in enumerate(times_percent):
            self.each_cpu[i].update(c.user, c.system, c.idle)

        self.__update_memory(self.memory, psutil.virtual_memory())
        self.__update_memory(self.swap, psutil.swap_memory())

    def __update_cpu(self, cpuper):
        sum_user = 0
        sum_system = 0
        sum_idle = 0
        l = len(cpuper)
        for cpu in cpuper:
            sum_user += cpu.user
            sum_system += cpu.system
            sum_idle += cpu.idle

        self.cpu.update(sum_user/l, sum_system/l, sum_idle/l)

    def __update_memory(self, mem, tuple_mem):
        mem.update(tuple_mem.total, tuple_mem.used)

#--------------------
# Updater
#--------------------

class Updater(object):

    def __init__(self, scr, system_status, layout):
        self.scr = scr
        self.system_status = system_status
        self.layout = layout

    def update(self):
        try:
            self.scr.erase()
            self.layout.draw()
            self.scr.refresh()
        except:
            self.scr.refresh()

        self.system_status.update()


#--------------------
# Arguments
#--------------------

class Arguments(object):

    def __init__(self, arg):
        self.no_color = arg["--no-color"]
        self.interval = float(arg["--interval"])
        self.no_tmux = arg["--no-tmux"]
        self.normal = arg["normal"]
        self.minimal = arg["minimal"]
        self.stack = arg["stack"]
        self.horizontal = arg["horizontal"]
        self.vertical = arg["vertical"]

        # default view is "normal".
        if not self.normal and not self.minimal and not self.stack:
            self.normal = True

        # default style is "horizontal".
        if not self.horizontal and not self.vertical:
            self.horizontal = True




import os
import subprocess

#=======================================
# tmux 
#=======================================

def call(command):
    """call tmux subcommand."""
    (stdout, stderr) = subprocess.Popen("tmux " + command, shell=True, stdout=subprocess.PIPE).communicate()
    return stdout

def get_version():
    version = call("-V")
    import re
    result = re.search(b"[\d\.]+", version)
    return float(result.group())

def in_tmux():
    """if process is in tmux, return True."""
    return bool(os.getenv("TMUX"))

def swap_pane():
    """swap current pane for previous pane."""
    call("swap-pane -D")

def move_last_pane():
    """move focus from current pane to previous pane."""
    call("last-pane")

def resize_pane(width=None, height=None):
    """resize pane"""
    resize_option = ""

    if width:  resize_option += " -x " + str(width+1)
    if height: resize_option += " -y " + str(height+1)

    call("resize-pane " + resize_option)

def split_window(vertical=True, horizontal=False, command=None):
    """new pane and exec command."""
    option = "-v" if vertical else "-h"

    if command:
        option += " \"" + command + "\""

    call("split-window " + option)




import curses

#=======================================
# Colors
#=======================================

#--------------------
# ColorTable
#--------------------

class ColorTable(object):
    """define color pair.
    must new this class in curses.wrapper hook function.
    """

    def __init__(self):
        self.pair_number = 0

        self.DEFAULT = curses.color_pair(0)
        self.BLACK = self.__define_color(curses.COLOR_BLACK, -1)
        self.WHITE = self.__define_color(curses.COLOR_WHITE, -1)
        self.BLUE = self.__define_color(curses.COLOR_BLUE, -1)
        self.CYAN = self.__define_color(curses.COLOR_CYAN, -1)
        self.GREEN = self.__define_color(curses.COLOR_GREEN, -1)
        self.MAGENTA = self.__define_color(curses.COLOR_MAGENTA, -1)
        self.RED = self.__define_color(curses.COLOR_RED, -1)
        self.YELLOW = self.__define_color(curses.COLOR_YELLOW, -1)

        self.GRAY = self.BLACK | curses.A_BOLD

    def __define_color(self, fg, bg):
        self.pair_number += 1
        curses.init_pair(self.pair_number, fg, bg)
        return curses.color_pair(self.pair_number)

#--------------------
# MonoColorTheme
#--------------------

class MonoColorTheme(object):
    """define monocolor theme."""

    def __init__(self, color):
        self.color= color

        self.LABEL = color.DEFAULT
        self.FRAME = color.DEFAULT
        self.PERCENT = color.DEFAULT

        self.CPU_GAUGE_USER = color.DEFAULT
        self.CPU_GAUGE_SYSTEM = color.DEFAULT

        self.MEM_GAUGE_USED = color.DEFAULT

#--------------------
# DefaultColorTheme
#--------------------

class DefaultColorTheme(MonoColorTheme):
    """define color theme."""

    def __init__(self, color):
        MonoColorTheme.__init__(self, color)

        self.PERCENT = color.GRAY

        self.CPU_GAUGE_USER = color.GREEN
        self.CPU_GAUGE_SYSTEM = color.RED

        self.MEM_GAUGE_USED = color.GREEN





from setuptools import setup

import ttop 

def join_files(*files):
    content = ""
    for name in files:
        f = open(name)
        content += f.read() + "\n"
        f.close()
    return content

setup(
    name = 'ttop',
    version = ttop.__version__,
    description = ttop.__doc__.strip(),
    long_description = join_files("README.rst", "CHANGES.rst"),
    url = ttop.__homepage__,
    license = ttop.__license__,
    author = ttop.__author__,
    author_email = ttop.__email__,
    packages = ["ttop"],
    entry_points = {
        "console_scripts": ["ttop = ttop.ttop:main"]
    },
    install_requires = open("requirements.txt").read().splitlines(),
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Environment :: Console :: Curses',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Unix',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Topic :: Utilities',
    ]
)



"""
ttop is CUI graphical system monitr.
"""

__author__ = "ton1517"
__email__ = "tonton1517@gmail.com"
__homepage__ = "https://github.com/ton1517/ttop"
__version__ = "0.6.2"
__license__ = "MIT License"
